disposeClientOnUnmount property
Tear down the client (and any session) when this widget unmounts. Set false if you own the client elsewhere and reuse it.
Implementation
final bool disposeClientOnUnmount;
Tear down the client (and any session) when this widget unmounts. Set false if you own the client elsewhere and reuse it.
final bool disposeClientOnUnmount;