VoicebotResolvedTheme class final

A VoicebotTheme with all nullable colors/styles resolved against the ambient Material theme. Built by VoicebotTheme.resolve; widgets read this.

Annotations

Constructors

VoicebotResolvedTheme({required VoicebotTheme base, required Color buttonBackground, required Color buttonForeground, required Color accent, required Color pulseColor, required Color panelBackground, required Color userBubbleColor, required Color userTextColor, required Color botBubbleColor, required Color botTextColor, required TextStyle titleStyle, required TextStyle bubbleTextStyle})
const

Properties

accent Color
final
base VoicebotTheme
final
botBubbleColor Color
final
botTextColor Color
final
bubbleRadius double
no setter
bubbleTextStyle TextStyle
final
buttonBackground Color
final
buttonElevation double
no setter
buttonForeground Color
final
buttonIcon IconData?
no setter
buttonSize double
no setter
corner VoicebotCorner
no setter
hashCode int
The hash code for this object.
no setterinherited
labels VoicebotLabels
no setter
margin EdgeInsets
no setter
panelBackground Color
final
panelHeightFactor double
no setter
panelMaxWidth double
no setter
panelRadius double
no setter
pulseColor Color
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spacing double
no setter
titleStyle TextStyle
final
userBubbleColor Color
final
userTextColor Color
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited