maybeOf static method
The nearest ancestor theme, or null if none was provided.
Implementation
static VoicebotTheme? maybeOf(BuildContext context) => context
.dependOnInheritedWidgetOfExactType<VoicebotThemeProvider>()
?.theme;
The nearest ancestor theme, or null if none was provided.
static VoicebotTheme? maybeOf(BuildContext context) => context
.dependOnInheritedWidgetOfExactType<VoicebotThemeProvider>()
?.theme;